@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 use List::Util qw( pairs );
@@ -52,7 +52,9 @@ be made more stable.
 
 =cut
 
-=head2 $pmat = Devel::MAT->load( $path, %args )
+=head2 load
+
+   $pmat = Devel::MAT->load( $path, %args )
 
 Loads a heap dump file from the given path, and returns a new C<Devel::MAT>
 instance wrapping it.
@@ -74,7 +76,9 @@ sub load
 
 =cut
 
-=head2 $df = $pmat->dumpfile
+=head2 dumpfile
+
+   $df = $pmat->dumpfile
 
 Returns the underlying L<Devel::MAT::Dumpfile> instance backing this analysis
 object.
@@ -87,7 +91,9 @@ sub dumpfile
    return $self->{df};
 }
 
-=head2 @tools = $pmat->available_tools
+=head2 available_tools
+
+   @tools = $pmat->available_tools
 
 Lists the L<Devel::MAT::Tool> classes that are installed and available.
 
@@ -117,7 +123,9 @@ Lists the L<Devel::MAT::Tool> classes that are installed and available.
    }
 }
 
-=head2 $tool = $pmat->load_tool( $name )
+=head2 load_tool
+
+   $tool = $pmat->load_tool( $name )
 
 Loads the named L<Devel::MAT::Tool> class.
 
@@ -135,7 +143,9 @@ sub load_tool
    return $self->{tools}{$name} ||= $tool_class->new( $self, %args );
 }
 
-=head2 $node = $pmat->inref_graph( $sv, %opts )
+=head2 inref_graph
+
+   $node = $pmat->inref_graph( $sv, %opts )
 
 Traces the tree of inrefs from C<$sv> back towards the known roots, returning
 a L<Devel::MAT::Graph> node object representing it, within a graph of reverse
@@ -227,15 +237,17 @@ sub inref_graph
    return $graph->get_sv_node( $sv );
 }
 
-=head2 $sv = $pmat->find_symbol( $name )
+=head2 find_symbol
+
+   $sv = $pmat->find_symbol( $name )
 
 Attempts to walk the symbol table looking for a symbol of the given name,
 which must include the sigil.
 
- $Package::Name::symbol_name => to return a SCALAR SV
- @Package::Name::symbol_name => to return an ARRAY SV
- %Package::Name::symbol_name => to return a HASH SV
- &Package::Name::symbol_name => to return a CODE SV
+   $Package::Name::symbol_name => to return a SCALAR SV
+   @Package::Name::symbol_name => to return an ARRAY SV
+   %Package::Name::symbol_name => to return a HASH SV
+   &Package::Name::symbol_name => to return a CODE SV
 
 =cut
 
@@ -268,7 +280,9 @@ sub find_symbol
    return $sv;
 }
 
-=head2 $gv = $pmat->find_glob( $name )
+=head2 find_glob
+
+   $gv = $pmat->find_glob( $name )
 
 Attempts to walk to the symbol table looking for a symbol of the given name,
 returning the C<GLOB> object if found.
