@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Context;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -74,7 +74,9 @@ sub load_v0_1
 
 =cut
 
-=head2 $gimme = $ctx->gimme
+=head2 gimme
+
+   $gimme = $ctx->gimme
 
 Returns the gimme value of the call context.
 
@@ -87,11 +89,17 @@ sub gimme
    return $GIMMES[ $self->{gimme} ];
 }
 
-=head2 $file = $ctx->file
+=head2 file
 
-=head2 $line = $ctx->line
+=head2 line
 
-=head2 $location = $ctx->location
+=head2 location
+
+   $file = $ctx->file
+
+   $line = $ctx->line
+
+   $location = $ctx->location
 
 Returns the file, line or location as (C<FILE line LINE>).
 
@@ -108,7 +116,7 @@ sub location
 
 package Devel::MAT::Context::SUB;
 use base qw( Devel::MAT::Context );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 1 );
 
 =head1 Devel::MAT::Context::SUB
@@ -127,6 +135,8 @@ sub load
    ( $self->{olddepth} ) = unpack "$df->{u32_fmt}", $bytes;
 
    ( $self->{cv_at}, $self->{args_at} ) = @$ptrs;
+
+   undef $self->{args_at} if $df->perlversion ge "5.23.8";
 }
 
 sub _load_v0_1
@@ -138,22 +148,32 @@ sub _load_v0_1
 
    $self->{cv_at}   = $df->_read_ptr;
    $self->{args_at} = $df->_read_ptr;
+
+   undef $self->{args_at} if $df->perlversion ge "5.23.8";
 }
 
-=head2 $cv = $ctx->cv
+=head2 cv
+
+   $cv = $ctx->cv
 
 Returns the CV which this call is to.
 
-=head2 $args = $ctx->args
+=head2 args
+
+   $args = $ctx->args
 
 Returns the arguments AV which represents the C<@_> argument array.
 
-=head2 $olddepth = $ctx->olddepth
+=head2 olddepth
+
+   $olddepth = $ctx->olddepth
 
 Returns the old depth of the context (that is, the depth the CV would be at
 after this context returns).
 
-=head2 $depth = $ctx->depth
+=head2 depth
+
+   $depth = $ctx->depth
 
 Returns the actual depth of the context. This is inferred at load time by
 considering the C<olddepth> of the next inner-nested call to the same CV, or
@@ -162,7 +182,19 @@ from the actual C<depth> of the CV is no other call exists.
 =cut
 
 sub cv   { my $self = shift; return $self->{df}->sv_at( $self->{cv_at} ) }
-sub args { my $self = shift; return $self->{df}->sv_at( $self->{args_at} ) }
+
+sub args
+{
+   my $self = shift;
+   # Perl 5.23.8 removed blk_sub.argarray so we have to go the long way round
+   $self->{args_at} //= do {
+      my $cv = $self->cv;
+      my $args = $cv->pad( $self->depth )->elem( 0 );
+      $args->addr;
+   };
+
+   return $self->{df}->sv_at( $self->{args_at} );
+}
 
 sub olddepth { return $_[0]->{olddepth} }
 
@@ -171,7 +203,7 @@ sub depth      { return $_[0]->{depth} }
 
 package Devel::MAT::Context::TRY;
 use base qw( Devel::MAT::Context );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 2 );
 
 =head1 Devel::MAT::Context::TRY
@@ -186,7 +218,7 @@ sub _load_v0_1 {}
 
 package Devel::MAT::Context::EVAL;
 use base qw( Devel::MAT::Context );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 3 );
 
 =head1 Devel::MAT::Context::EVAL
@@ -203,7 +235,7 @@ sub load
    ( $self->{code_at} ) = @$ptrs;
 }
 
-sub _load
+sub _load_v0_1
 {
    my $self = shift;
    my ( $df ) = @_;
@@ -211,7 +243,9 @@ sub _load
    $self->{code_at} = $df->_read_ptr;
 }
 
-=head2 $sv = $ctx->code
+=head2 code
+
+   $sv = $ctx->code
 
 Returns the SV containing the text string being evaluated.
 
