@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Dumper;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use File::Basename qw( basename );
 
@@ -50,14 +50,14 @@ Installs a handler for the special C<__DIE__> signal to write a dump file when
 C<die()> is about to cause a fatal signal. This is more reliable at catching
 the callstack and memory state than using an C<END> block.
 
- $ perl -MDevel::MAT::Dumper=-dump_at_DIE ...
+   $ perl -MDevel::MAT::Dumper=-dump_at_DIE ...
 
 =head2 -dump_at_END
 
 Installs an C<END> block which writes a dump file at C<END> time, just before
 the interpreter exits.
 
- $ perl -MDevel::MAT::Dumper=-dump_at_END ...
+   $ perl -MDevel::MAT::Dumper=-dump_at_END ...
 
 =head2 -dump_at_SIGABRT
 
@@ -65,7 +65,7 @@ Installs a handler for C<SIGABRT> to write a dump file if the signal is
 received. After dumping the file, the signal handler is removed and the signal
 re-raised.
 
- $ perl -MDevel::MAT::Dumper=-dump_at_SIGABRT ...
+   $ perl -MDevel::MAT::Dumper=-dump_at_SIGABRT ...
 
 =head2 -dump_at_SIGQUIT
 
@@ -73,14 +73,14 @@ Installs a handler for C<SIGQUIT> to write a dump file if the signal is
 received. The signal handler will remain in place and can be used several
 times.
 
- $ perl -MDevel::MAT::Dumper=-dump_at_SIGQUIT ...
+   $ perl -MDevel::MAT::Dumper=-dump_at_SIGQUIT ...
 
 =head2 -file $PATH
 
 Sets the name of the file which is automatically dumped; defaults to basename
 F<$0.pmat> if not supplied.
 
- $ perl -MDevel::MAT::Dumper=-file,foo.pmat ...
+   $ perl -MDevel::MAT::Dumper=-file,foo.pmat ...
 
 If the pattern contains C<NNN>, this will be replaced by a unique serial
 number per written file, starting from 0. This may be helpful in the case of
@@ -185,11 +185,15 @@ sub import
 
 These functions are not exported, they must be called fully-qualified.
 
-=head2 dump( $path )
+=head2 dump
+
+   dump( $path )
 
 Writes a heap dump to the named file
 
-=head2 dumpfh( $fh )
+=head2 dumpfh
+
+   dumpfh( $fh )
 
 Writes a heap dump to the given filehandle (which must be a plain OS-level
 filehandle, though does not need to be a regular file, or seekable).
