@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Dumpfile;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 use IO::Handle;   # ->read
@@ -110,7 +110,9 @@ foreach (
 
 =cut
 
-=head2 $df = Devel::MAT::Dumpfile->load( $path, %args )
+=head2 load
+
+   $df = Devel::MAT::Dumpfile->load( $path, %args )
 
 Loads a heap dump file from the given path, and returns a new
 C<Devel::MAT::Dumpfile> instance representing it.
@@ -450,7 +452,9 @@ sub _read_ctx
 
 =cut
 
-=head2 $version = $df->perlversion
+=head2 perlversion
+
+   $version = $df->perlversion
 
 Returns the version of perl that the heap dump file was created by, as a
 string in the form C<5.14.2>.
@@ -464,7 +468,9 @@ sub perlversion
    return join ".", $v>>24, ($v>>16) & 0xff, $v&0xffff;
 }
 
-=head2 $endian = $df->endian
+=head2 endian
+
+   $endian = $df->endian
 
 Returns the endian direction of the perl that the heap dump was created by, as
 either C<big> or C<little>.
@@ -477,7 +483,9 @@ sub endian
    return $self->{big_endian} ? "big" : "little";
 }
 
-=head2 $len = $df->uint_len
+=head2 uint_len
+
+   $len = $df->uint_len
 
 Returns the length in bytes of a uint field of the perl that the heap dump was
 created by.
@@ -490,7 +498,9 @@ sub uint_len
    return $self->{uint_len};
 }
 
-=head2 $len = $df->ptr_len
+=head2 ptr_len
+
+   $len = $df->ptr_len
 
 Returns the length in bytes of a pointer field of the perl that the heap dump
 was created by.
@@ -503,7 +513,9 @@ sub ptr_len
    return $self->{ptr_len};
 }
 
-=head2 $len = $df->nv_len
+=head2 nv_len
+
+   $len = $df->nv_len
 
 Returns the length in bytes of a double field of the perl that the heap dump
 was created by.
@@ -516,7 +528,9 @@ sub nv_len
    return $self->{nv_len};
 }
 
-=head2 $ithreads = $df->ithreads
+=head2 ithreads
+
+   $ithreads = $df->ithreads
 
 Returns a boolean indicating whether ithread support was enabled in the perl
 that the heap dump was created by.
@@ -529,11 +543,15 @@ sub ithreads
    return $self->{ithreads};
 }
 
-=head2 %roots = $df->roots
+=head2 roots
+
+   %roots = $df->roots
 
 Returns a key/value pair list giving the names and SVs at each of the roots.
 
-=head2 %roots = $df->roots_strong
+=head2 roots_strong
+
+   %roots = $df->roots_strong
 
 Returns a key/value pair list giving the names and SVs at each of the roots
 that count as strong references.
@@ -558,44 +576,48 @@ sub roots_strong
    return pairmap { $a =~ m/^\+(.*)/ ? ( $1 => $b ) : () } $self->_roots;
 }
 
-=head2 $sv = $df->ROOT
+=head2 ROOTS
+
+   $sv = $df->ROOT
 
 For each of the root names given below, a method exists with that name which
 returns the SV at that root:
 
- main_cv
- defstash
- mainstack
- beginav
- checkav
- unitcheckav
- initav
- endav
- strtabhv
- envgv
- incgv
- statgv
- statname
- tmpsv
- defgv
- argvgv
- argvoutgv
- argvout_stack
- fdpidav
- preambleav
- modglobalhv
- regex_padav
- sortstash
- firstgv
- secondgv
- debstash
- stashcache
- isarev
- registered_mros
+   main_cv
+   defstash
+   mainstack
+   beginav
+   checkav
+   unitcheckav
+   initav
+   endav
+   strtabhv
+   envgv
+   incgv
+   statgv
+   statname
+   tmpsv
+   defgv
+   argvgv
+   argvoutgv
+   argvout_stack
+   fdpidav
+   preambleav
+   modglobalhv
+   regex_padav
+   sortstash
+   firstgv
+   secondgv
+   debstash
+   stashcache
+   isarev
+   registered_mros
 
 =cut
 
-=head2 @svs = $df->heap
+=head2 heap
+
+   @svs = $df->heap
 
 Returns all of the heap-allocated SVs, in no particular order
 
@@ -607,7 +629,9 @@ sub heap
    return values %{ $self->{heap} };
 }
 
-=head2 @ctxs = $df->contexts
+=head2 contexts
+
+   @ctxs = $df->contexts
 
 Returns a list of L<Devel::MAT::Context> objects representing the call context
 stack in the dumpfile.
@@ -620,7 +644,9 @@ sub contexts
    return @{ $self->{contexts} };
 }
 
-=head2 $sv = $df->sv_at( $addr )
+=head2 sv_at
+
+   $sv = $df->sv_at( $addr )
 
 Returns the SV at the given address, or C<undef> if one does not exist.
 
