@@ -1,16 +1,16 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Graph;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
-use Struct::Dumb 'readonly_struct';
+use Struct::Dumb 0.07 'readonly_struct';
 
 =head1 NAME
 
@@ -29,7 +29,9 @@ tasks.
 
 =cut
 
-=head2 $graph = Devel::MAT::Graph->new( $dumpfile )
+=head2 new
+
+   $graph = Devel::MAT::Graph->new( $dumpfile )
 
 Constructs a new C<Devel::MAT::Graph> instance backed by the given dumpfile
 (which is only actually used to make the C<< $node->sv >> method work).
@@ -55,7 +57,9 @@ sub new
 
 =cut
 
-=head2 $graph->add_sv( $sv )
+=head2 add_sv
+
+   $graph->add_sv( $sv )
 
 Makes the graph aware of the given L<Devel::MAT::SV>. This is not strictly
 necessary before calling C<add_ref> or C<add_root>, but ensures that C<has_sv>
@@ -74,7 +78,9 @@ sub add_sv
    return $self;
 }
 
-=head2 $graph->add_ref( $from_sv, $to_sv, $desc )
+=head2 add_ref
+
+   $graph->add_ref( $from_sv, $to_sv, $desc )
 
 Adds an edge to the graph, from and to the given SVs, with the given
 description.
@@ -95,7 +101,9 @@ sub add_ref
    return $self;
 }
 
-=head2 $graph->add_root( $from_sv, $desc )
+=head2 add_root
+
+   $graph->add_root( $from_sv, $desc )
 
 Adds a root edge to the graph, at the given SV with the given description.
 
@@ -115,7 +123,9 @@ sub add_root
 
 =cut
 
-=head2 $bool = $graph->has_sv( $sv )
+=head2 has_sv
+
+   $bool = $graph->has_sv( $sv )
 
 Returns true if the graph has edges or roots for the given SV, or it has at
 least been given to C<add_sv>.
@@ -134,7 +144,9 @@ sub has_sv
               $self->{roots_from}{$addr} );
 }
 
-=head2 $node = $graph->get_sv_node( $sv )
+=head2 get_sv_node
+
+   $node = $graph->get_sv_node( $sv )
 
 Returns a C<Node> object for the given SV.
 
@@ -153,7 +165,9 @@ sub get_sv_node
    );
 }
 
-=head2 @desc_nodes = $graph->get_root_nodes
+=head2 get_root_nodes
+
+   @desc_nodes = $graph->get_root_nodes
 
 Returns an even-sized list of pairs, containing root descriptions and the
 nodes having those roots, in no particular order.
@@ -179,11 +193,15 @@ The values returned by C<get_sv_node> respond to the following methods:
 
 sub new { my $class = shift; bless { @_ }, $class }
 
-=head2 $graph = $node->graph
+=head2 graph
+
+   $graph = $node->graph
 
 Returns the containing C<Devel::MAT::Graph> instance.
 
-=head2 $addr = $node->addr
+=head2 addr
+
+   $addr = $node->addr
 
 Returns the address of the SV represented by this node.
 
@@ -192,7 +210,9 @@ Returns the address of the SV represented by this node.
 sub graph { $_[0]->{graph} }
 sub addr  { $_[0]->{addr}  }
 
-=head2 $sv = $node->sv
+=head2 sv
+
+   $sv = $node->sv
 
 Returns the SV object itself, as taken from the dumpfile instance.
 
@@ -200,14 +220,16 @@ Returns the SV object itself, as taken from the dumpfile instance.
 
 sub sv { $_[0]->graph->{df}->sv_at( $_[0]->addr ) }
 
-=head2 @roots = $node->roots
+=head2 roots
+
+   @roots = $node->roots
 
 Returns any root descriptions given (by calls to C<< $graph->add_root >> for
 the SV at this node.
 
- $graph->add_root( $sv, $desc );
+   $graph->add_root( $sv, $desc );
 
- ( $desc, ... ) = $graph->get_sv_node( $sv )->roots
+   ( $desc, ... ) = $graph->get_sv_node( $sv )->roots
 
 =cut
 
@@ -217,17 +239,21 @@ sub roots
    return @{ $self->graph->{roots_from}{$self->addr} // [] };
 }
 
-=head2 @edges = $node->edges_out
+=head2 edges_out
+
+   @edges = $node->edges_out
 
 Returns an even-sized list of any edge descriptions and more C<Node> objects
 given as references (by calls to C<< $graph->add_ref >>) from the SV at this
 node.
 
- $graph->add_ref( $from_sv, $to_sv, $desc )
+   $graph->add_ref( $from_sv, $to_sv, $desc )
 
- ( $desc, $to_edge, ... ) = $graph->get_sv_node( $from_sv )->edges_out
+   ( $desc, $to_edge, ... ) = $graph->get_sv_node( $from_sv )->edges_out
 
-=head2 $n_edges = $node->edges_out
+=head2 edges_out (scalar)
+
+   $n_edges = $node->edges_out
 
 In scalar context, returns the I<number of edges> that exist; i.e. half the
 size of the pairlist that would be returned in list context.
@@ -245,16 +271,20 @@ sub edges_out
    } @$edges;
 }
 
-=head2 @edges = $node->edges_in
+=head2 edges_in
+
+   @edges = $node->edges_in
 
 Similar to C<edges_out>, but returns edges in the opposite direction; i.e.
 edges of references to this node.
 
- $graph->add_ref( $from_sv, $to_sv, $desc )
+   $graph->add_ref( $from_sv, $to_sv, $desc )
 
- ( $desc, $from_edge, ... ) = $graph->get_sv_node( $to_sv )->edges_in
+   ( $desc, $from_edge, ... ) = $graph->get_sv_node( $to_sv )->edges_in
 
-=head2 $n_edges = $node->edges_out
+=head2 edges_in (scalar)
+
+   $n_edges = $node->edges_out
 
 In scalar context, returns the I<number of edges> that exist; i.e. half the
 size of the pairlist that would be returned in list context.
