@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::SV;
 
@@ -10,7 +10,7 @@ use warnings;
 use feature qw( switch );
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -21,7 +21,7 @@ require Devel::MAT;
 
 use constant immortal => 0;
 
-use Struct::Dumb qw( readonly_struct );
+use Struct::Dumb 0.07 qw( readonly_struct );
 readonly_struct Reference => [qw( name strength sv )];
 
 =head1 NAME
@@ -91,21 +91,27 @@ sub new
 
 =cut
 
-=head2 $type = $sv->type
+=head2 type
+
+   $type = $sv->type
 
 Returns the major type of the SV. This is the class name minus the
 C<Devel::MAT::SV::> prefix.
 
 =cut
 
-=head2 $desc = $sv->desc
+=head2 desc
+
+   $desc = $sv->desc
 
 Returns a string describing the type of the SV and giving a short detail of
 its contents. The exact details depends on the SV type.
 
 =cut
 
-=head2 $desc = $sv->desc_addr
+=head2 desc_addr
+
+   $desc = $sv->desc_addr
 
 Returns a string describing the SV as with C<desc> and giving its address in
 hex. A useful way to uniquely identify the SV when printing.
@@ -118,7 +124,9 @@ sub desc_addr
    return sprintf "%s at %#x", $self->desc, $self->addr;
 }
 
-=head2 $addr = $sv->addr
+=head2 addr
+
+   $addr = $sv->addr
 
 Returns the address of the SV
 
@@ -126,11 +134,15 @@ Returns the address of the SV
 
 # XS accessor
 
-=head2 $count = $sv->refcnt
+=head2 refcnt
+
+   $count = $sv->refcnt
 
 Returns the C<SvREFCNT> reference count of the SV
 
-=head2 $count = $sv->refcount_adjusted
+=head2 refcount_adjusted
+
+   $count = $sv->refcount_adjusted
 
 Returns the reference count of the SV, adjusted to take account of the fact
 that the C<SvREFCNT> value of the backrefs list of a hash or weakly-referenced
@@ -142,7 +154,9 @@ object is artificially high.
 
 sub refcount_adjusted { shift->refcnt }
 
-=head2 $stash = $sv->blessed
+=head2 blessed
+
+   $stash = $sv->blessed
 
 If the SV represents a blessed object, returns the stash SV. Otherwise returns
 C<undef>.
@@ -155,7 +169,9 @@ sub blessed
    return $self->df->sv_at( $self->blessed_at );
 }
 
-=head2 $size = $sv->size
+=head2 size
+
+   $size = $sv->size
 
 Returns the (approximate) size in bytes of the SV
 
@@ -163,7 +179,9 @@ Returns the (approximate) size in bytes of the SV
 
 # XS accessor
 
-=head2 ( $type, $sv, $type, $sv, ... ) = $sv->magic
+=head2 magic
+
+   ( $type, $sv, $type, $sv, ... ) = $sv->magic
 
 Returns a pair list of magic applied to the SV; each giving the type and
 target SV.
@@ -182,7 +200,9 @@ sub magic
                 ( $ptr_at ? ( $type => $df->sv_at( $ptr_at ) ) : () ) } @$magic;
 }
 
-=head2 $av_or_rv = $sv->backrefs
+=head2 backrefs
+
+   $av_or_rv = $sv->backrefs
 
 Returns backrefs SV, which may be an AV containing the back references, or
 if there is only one, the REF SV itself referring to this.
@@ -213,7 +233,9 @@ sub more_magic
    push @{ $self->{magic} }, [ $type => $flags, $obj_at, $ptr_at ];
 }
 
-=head2 @refs = $sv->outrefs
+=head2 outrefs
+
+   @refs = $sv->outrefs
 
 Returns a list of Reference objects for each of the SVs that this one refers
 to, either directly by strong or weak reference, indirectly via RV, or
@@ -284,23 +306,33 @@ sub _outrefs_matching
 
 sub outrefs { shift->_outrefs_matching( undef ) }
 
-=head2 @refs = $sv->outrefs_strong
+=head2 outrefs_strong
+
+   @refs = $sv->outrefs_strong
 
 Returns the subset of C<outrefs> that are direct strong references.
 
-=head2 @refs = $sv->outrefs_weak
+=head2 outrefs_weak
+
+   @refs = $sv->outrefs_weak
 
 Returns the subset of C<outrefs> that are direct weak references.
 
-=head2 @refs = $sv->outrefs_direct
+=head2 outrefs_direct
+
+   @refs = $sv->outrefs_direct
 
 Returns the subset of C<outrefs> that are direct strong or weak references.
 
-=head2 @refs = $sv->outrefs_indirect
+=head2 outrefs_indirect
+
+   @refs = $sv->outrefs_indirect
 
 Returns the subset of C<outrefs> that are indirect references via RVs.
 
-=head2 @refs = $sv->outrefs_inferred
+=head2 outrefs_inferred
+
+   @refs = $sv->outrefs_inferred
 
 Returns the subset of C<outrefs> that are not directly stored in the SV
 structure, but instead inferred by C<Devel::MAT> itself.
@@ -332,7 +364,7 @@ boolean true and false. They are
 
 package Devel::MAT::SV::Immortal;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 use constant immortal => 1;
 sub new {
    my $class = shift;
@@ -345,13 +377,13 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::UNDEF;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
 package Devel::MAT::SV::YES;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 sub desc { "YES" }
 sub type { "SCALAR" }
 
@@ -366,7 +398,7 @@ sub name {}
 
 package Devel::MAT::SV::NO;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 sub desc { "NO" }
 sub type { "SCALAR" }
 
@@ -381,7 +413,7 @@ sub name {}
 
 package Devel::MAT::SV::Unknown;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 0xff );
 
 sub desc { "UNKNOWN" }
@@ -390,7 +422,7 @@ sub _outrefs {}
 
 package Devel::MAT::SV::GLOB;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 1 );
 
 =head1 Devel::MAT::SV::GLOB
@@ -422,11 +454,17 @@ sub _fixup
    $_ and $_->_set_glob_at( $self->addr ) for $self->scalar, $self->array, $self->hash, $self->code;
 }
 
-=head2 $file = $gv->file
+=head2 file
 
-=head2 $line = $gv->line
+=head2 line
 
-=head2 $location = $gv->location
+=head2 location
+
+   $file = $gv->file
+
+   $line = $gv->line
+
+   $location = $gv->location
 
 Returns the filename, line number, or combined location (C<FILE line LINE>)
 that the GV first appears at.
@@ -443,7 +481,9 @@ sub location
    defined $file ? "$file line $line" : undef
 }
 
-=head2 $stash = $gv->stash
+=head2 stash
+
+   $stash = $gv->stash
 
 Returns the stash to which the GV belongs.
 
@@ -451,19 +491,33 @@ Returns the stash to which the GV belongs.
 
 sub stash  { my $self = shift; $self->df->sv_at( $self->stash_at  ) }
 
-=head2 $sv = $gv->scalar
+=head2 scalar
 
-=head2 $av = $gv->array
+=head2 array
 
-=head2 $hv = $gv->hash
+=head2 hash
 
-=head2 $cv = $gv->code
+=head2 code
 
-=head2 $gv = $gv->egv
+=head2 egv
 
-=head2 $io = $gv->io
+=head2 io
 
-=head2 $form = $gv->form
+=head2 form
+
+   $sv = $gv->scalar
+
+   $av = $gv->array
+
+   $hv = $gv->hash
+
+   $cv = $gv->code
+
+   $gv = $gv->egv
+
+   $io = $gv->io
+
+   $form = $gv->form
 
 Return the SV in the various glob slots.
 
@@ -521,7 +575,7 @@ sub _outrefs
 
 package Devel::MAT::SV::SCALAR;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 2 );
 
 =head1 Devel::MAT::SV::SCALAR
@@ -556,23 +610,33 @@ sub load
    $flags and die sprintf "Unrecognised SCALAR flags %02x\n", $flags;
 }
 
-=head2 $uv = $sv->uv
+=head2 uv
+
+   $uv = $sv->uv
 
 Returns the integer numeric portion as an unsigned value, if valid, or C<undef>.
 
-=head2 $iv = $sv->iv
+=head2 iv
+
+   $iv = $sv->iv
 
 Returns the integer numeric portion as a signed value, if valid, or C<undef>.
 
-=head2 $nv = $sv->nv
+=head2 nv
+
+   $nv = $sv->nv
 
 Returns the floating numeric portion, if valid, or C<undef>.
 
-=head2 $pv = $sv->pv
+=head2 pv
+
+   $pv = $sv->pv
 
 Returns the string portion, if valid, or C<undef>.
 
-=head2 $pvlen = $sv->pvlen
+=head2 pvlen
+
+   $pvlen = $sv->pvlen
 
 Returns the length of the string portion, if valid, or C<undef>.
 
@@ -580,7 +644,9 @@ Returns the length of the string portion, if valid, or C<undef>.
 
 # XS accessors
 
-=head2 $str = $sv->qq_pv( $maxlen )
+=head2 qq_pv
+
+   $str = $sv->qq_pv( $maxlen )
 
 Returns the PV string, if defined, suitably quoted. If C<$maxlen> is defined
 and the PV is longer than this, it is truncated and C<...> is appended after
@@ -612,7 +678,9 @@ sub qq_pv
    return $pv;
 }
 
-=head2 $stash = $sv->ourstash
+=head2 ourstash
+
+   $stash = $sv->ourstash
 
 Returns the stash of the SCALAR, if it is an 'C<our>' variable.
 
@@ -653,7 +721,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REF;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 3 );
 
 =head1 Devel::MAT::SV::REF
@@ -680,7 +748,9 @@ sub load
    $flags and die sprintf "Unrecognised REF flags %02x\n", $flags;
 }
 
-=head2 $svrv = $sv->rv
+=head2 rv
+
+   $svrv = $sv->rv
 
 Returns the SV referred to by the reference.
 
@@ -688,7 +758,9 @@ Returns the SV referred to by the reference.
 
 sub rv { my $self = shift; return $self->df->sv_at( $self->rv_at ) }
 
-=head2 $weak = $sv->is_weak
+=head2 is_weak
+
+   $weak = $sv->is_weak
 
 Returns true if the SV is a weakened RV reference.
 
@@ -696,7 +768,9 @@ Returns true if the SV is a weakened RV reference.
 
 # XS accessor
 
-=head2 $stash = $sv->ourstash
+=head2 ourstash
+
+   $stash = $sv->ourstash
 
 Returns the stash of the SCALAR, if it is an 'C<our>' variable.
 
@@ -724,7 +798,7 @@ sub _outrefs
 
 package Devel::MAT::SV::ARRAY;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 4 );
 
 =head1 Devel::MAT::SV::ARRAY
@@ -752,12 +826,16 @@ sub load
    $self->_set_array_fields( $flags || 0, [ $n ? $df->_read_ptrs($n) : () ] );
 }
 
-=head2 $unreal = $av->is_unreal
+=head2 is_unreal
+
+   $unreal = $av->is_unreal
 
 Returns true if the C<AvREAL()> flag is not set on the array - i.e. that its
 SV pointers do not contribute to the C<SvREFCNT> of the SVs it points at.
 
-=head2 $backrefs = $av->is_backrefs
+=head2 is_backrefs
+
+   $backrefs = $av->is_backrefs
 
 Returns true if the array contains the backrefs list of a hash or
 weakly-referenced object.
@@ -773,7 +851,9 @@ sub name
    return '@' . $self->df->sv_at( $glob_at )->stashname;
 }
 
-=head2 @svs = $av->elems
+=head2 elems
+
+   @svs = $av->elems
 
 Returns all of the element SVs in a list
 
@@ -790,7 +870,9 @@ sub elems
    return map { $df->sv_at( $self->elem_at( $_ ) ) } 0 .. $n-1;
 }
 
-=head2 $sv = $av->elem( $index )
+=head2 elem
+
+   $sv = $av->elem( $index )
 
 Returns the SV at the given index
 
@@ -836,7 +918,7 @@ sub _outrefs
 package Devel::MAT::SV::PADLIST;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 use constant type => "PADLIST";
 
 =head1 Devel::MAT::SV::PADLIST
@@ -872,7 +954,7 @@ sub _outrefs
 package Devel::MAT::SV::PADNAMES;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 use constant type => "PADNAMES";
 
 =head1 Devel::MAT::SV::PADNAMES
@@ -883,7 +965,9 @@ A subclass of ARRAY, this is used to represent the PADNAMES of a CODE SV.
 
 sub padcv { my $self = shift; return $self->df->sv_at( $self->padcv_at ) }
 
-=head2 $padname = $padnames->padname( $padix )
+=head2 padname
+
+   $padname = $padnames->padname( $padix )
 
 Returns the name of the lexical at the given index, or C<undef>
 
@@ -898,7 +982,9 @@ sub padname
    return $namepv->pv;
 }
 
-=head2 $padix = $padnames->padix_from_padname( $padname )
+=head2 padix_from_padname
+
+   $padix = $padnames->padix_from_padname( $padname )
 
 Returns the index of the lexical with the given name, or C<undef>
 
@@ -944,7 +1030,7 @@ sub _outrefs
 package Devel::MAT::SV::PAD;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 use constant type => "PAD";
 
 use List::Util qw( pairmap );
@@ -961,7 +1047,9 @@ sub desc
    return "PAD(" . scalar($self->elems) . ")";
 }
 
-=head2 ( $name, $sv, $name, $sv, ... ) = $pad->lexvars
+=head2 lexvars
+
+   ( $name, $sv, $name, $sv, ... ) = $pad->lexvars
 
 Returns a name/value list of the lexical variables in the pad.
 
@@ -1003,7 +1091,7 @@ sub _outrefs
 
 package Devel::MAT::SV::HASH;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 5 );
 
 =head1 Devel::MAT::SV::HASH
@@ -1059,7 +1147,9 @@ sub backrefs
    return $self->df->sv_at( $self->backrefs_at );
 }
 
-=head2 @keys = $hv->keys
+=head2 keys
+
+   @keys = $hv->keys
 
 Returns the set of keys present in the hash, as plain perl strings, in no
 particular order.
@@ -1068,7 +1158,9 @@ particular order.
 
 # XS accessor
 
-=head2 $sv = $hv->value( $key )
+=head2 value
+
+   $sv = $hv->value( $key )
 
 Returns the SV associated with the given key
 
@@ -1081,9 +1173,12 @@ sub value
    return $self->df->sv_at( $self->value_at( $key ) );
 }
 
-=head2 @svs = $hv->values
+=head2 values
 
-Returns all of the SVs stored as values, in no particular order.
+   @svs = $hv->values
+
+Returns all of the SVs stored as values, in no particular order (though, in an
+order corresponding to the order returned by C<keys>).
 
 =cut
 
@@ -1126,7 +1221,7 @@ sub _outrefs
 
 package Devel::MAT::SV::STASH;
 use base qw( Devel::MAT::SV::HASH );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 6 );
 
 =head1 Devel::MAT::SV::STASH
@@ -1157,13 +1252,21 @@ sub load
       @$strs;
 }
 
-=head2 $hv = $stash->mro_linear_all
+=head2 mro_linear_all
 
-=head2 $sv = $stash->mro_linearcurrent
+=head2 mro_linearcurrent
 
-=head2 $sv = $stash->mro_nextmethod
+=head2 mro_nextmethod
 
-=head2 $av = $stash->mro_isa
+=head2 mro_isa
+
+   $hv = $stash->mro_linear_all
+
+   $sv = $stash->mro_linearcurrent
+
+   $sv = $stash->mro_nextmethod
+
+   $av = $stash->mro_isa
 
 Returns the fields from the MRO structure
 
@@ -1174,7 +1277,9 @@ sub mro_linearcurrent { my $self = shift; return $self->df->sv_at( $self->{mro_l
 sub mro_nextmethod    { my $self = shift; return $self->df->sv_at( $self->{mro_nextmethod_at} ) }
 sub mro_isa           { my $self = shift; return $self->df->sv_at( $self->{mro_isa_at} ) }
 
-=head2 $cv = $stash->value_code( $key )
+=head2 value_code
+
+   $cv = $stash->value_code( $key )
 
 Returns the CODE associated with the given symbol name, if it exists, or
 C<undef> if not. This is roughly equivalent to
@@ -1202,7 +1307,9 @@ sub value_code
    die "TODO: value_code on non-GLOB, non-REF ${\ $sv->desc }";
 }
 
-=head2 $name = $stash->stashname
+=head2 stashname
+
+   $name = $stash->stashname
 
 Returns the name of the stash
 
@@ -1234,14 +1341,14 @@ sub _outrefs
 
 package Devel::MAT::SV::CODE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 7 );
 
 use Carp;
 
 use List::MoreUtils qw( uniq );
 
-use Struct::Dumb qw( readonly_struct );
+use Struct::Dumb 0.07 qw( readonly_struct );
 readonly_struct Padname => [qw( name ourstash )];
 
 =head1 Devel::MAT::SV::CODE
@@ -1361,30 +1468,48 @@ sub _fixup
 
          # Clear the obviously unused elements of lexnames and padlists
          foreach my $ix ( @$idxes ) {
-            $padnames->_clear_elem( $ix );
+            $padnames->_clear_elem( $ix ) if $padnames;
             $_ and $_->_clear_elem( $ix ) for @pads;
          }
       }
    }
 }
 
-=head2 $stash = $cv->stash
+=head2 stash
 
-=head2 $gv = $cv->glob
+=head2 glob
 
-=head2 $filename = $cv->file
+=head2 file
 
-=head2 $line = $cv->line
+=head2 line
 
-=head2 $scope_cv = $cv->scope
+=head2 scope
 
-=head2 $av = $cv->padlist
+=head2 padlist
 
-=head2 $sv = $cv->constval
+=head2 constval
 
-=head2 $addr = $cv->oproot
+=head2 oproot
 
-=head2 $depth = $cv->depth
+=head2 depth
+
+   $stash = $cv->stash
+
+   $gv = $cv->glob
+
+   $filename = $cv->file
+
+   $line = $cv->line
+
+   $scope_cv = $cv->scope
+
+   $av = $cv->padlist
+
+   $sv = $cv->constval
+
+   $addr = $cv->oproot
+
+   $depth = $cv->depth
 
 Returns the stash, glob, filename, line number, scope, padlist, constant value,
 oproot or depth of the code.
@@ -1399,7 +1524,9 @@ sub padlist  { my $self = shift; return $self->df->sv_at( $self->padlist_at ) }
 sub constval { my $self = shift; return $self->df->sv_at( $self->constval_at ) }
 # XS accessors: oproot, depth
 
-=head2 $location = $cv->location
+=head2 location
+
+   $location = $cv->location
 
 Returns C<FILE line LINE> if the line is defined, or C<FILE> if not.
 
@@ -1414,17 +1541,29 @@ sub location
    return $line ? "$file line $line" : $file;
 }
 
-=head2 $clone = $cv->is_clone
+=head2 is_clone
 
-=head2 $cloned = $cv->is_cloned
+=head2 is_cloned
 
-=head2 $xsub = $cv->is_xsub
+=head2 is_xsub
 
-=head2 $weak = $cv->is_weakoutside
+=head2 is_weakoutside
 
-=head2 $rc = $cv->is_cvgv_rc
+=head2 is_cvgv_rc
 
-=head2 $lexical = $cv->is_lexical
+=head2 is_lexical
+
+   $clone = $cv->is_clone
+
+   $cloned = $cv->is_cloned
+
+   $xsub = $cv->is_xsub
+
+   $weak = $cv->is_weakoutside
+
+   $rc = $cv->is_cvgv_rc
+
+   $lexical = $cv->is_lexical
 
 Returns the C<CvCLONE()>, C<CvCLONED()>, C<CvISXSUB()>, C<CvWEAKOUTSIDE()>,
 C<CvCVGV_RC()> and C<CvLEXICAL()> flags.
@@ -1433,7 +1572,9 @@ C<CvCVGV_RC()> and C<CvLEXICAL()> flags.
 
 # XS accessors
 
-=head2 $protosub = $cv->protosub
+=head2 protosub
+
+   $protosub = $cv->protosub
 
 Returns the protosub CV, if known, for a closure CV.
 
@@ -1441,7 +1582,9 @@ Returns the protosub CV, if known, for a closure CV.
 
 sub protosub { my $self = shift; return $self->df->sv_at( $self->protosub_at ); }
 
-=head2 @svs = $cv->constants
+=head2 constants
+
+   @svs = $cv->constants
 
 Returns a list of the SVs used as constants or method names in the code. On
 ithreads perl the constants are part of the padlist structure so this list is
@@ -1456,7 +1599,9 @@ sub constants
    return map { $df->sv_at($_) } @{ $self->{consts_at} || [] };
 }
 
-=head2 @svs = $cv->globrefs
+=head2 globrefs
+
+   @svs = $cv->globrefs
 
 Returns a list of the SVs used as GLOB references in the code. On ithreads
 perl the constants are part of the padlist structure so this list is
@@ -1488,7 +1633,9 @@ sub name
    return undef;
 }
 
-=head2 $padname = $cv->padname( $padix )
+=head2 padname
+
+   $padname = $cv->padname( $padix )
 
 Returns the name of the $padix'th lexical variable, or C<undef> if it doesn't
 have a name.
@@ -1507,7 +1654,9 @@ sub padname
    return $self->{padnames}[$padix];
 }
 
-=head2 $padix = $cv->padix_from_padname( $padname )
+=head2 padix_from_padname
+
+   $padix = $cv->padix_from_padname( $padname )
 
 Returns the index of the first lexical variable with the given pad name, or
 C<undef> if one does not exist.
@@ -1529,7 +1678,9 @@ sub padix_from_padname
    return undef;
 }
 
-=head2 $padnames = $cv->padnames
+=head2 padnames
+
+   $padnames = $cv->padnames
 
 Returns the AV reference directly which stores the pad names.
 
@@ -1547,7 +1698,9 @@ sub padnames
       // croak "${\ $self->desc } PADNAMES is not accessible";
 }
 
-=head2 @pads = $cv->pads
+=head2 pads
+
+   @pads = $cv->pads
 
 Returns a list of the actual pad AVs.
 
@@ -1559,7 +1712,9 @@ sub pads
    return $self->{pads} ? @{ $self->{pads} } : ();
 }
 
-=head2 $pad = $cv->pad( $depth )
+=head2 pad
+
+   $pad = $cv->pad( $depth )
 
 Returns the PAD at the given depth (given by 1-based index).
 
@@ -1630,7 +1785,7 @@ sub _outrefs
 
 package Devel::MAT::SV::IO;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 8 );
 
 sub load
@@ -1660,7 +1815,7 @@ sub _outrefs
 
 package Devel::MAT::SV::LVALUE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 9 );
 
 sub load
@@ -1693,7 +1848,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REGEXP;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 10 );
 
 sub load {}
@@ -1704,7 +1859,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::FORMAT;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 11 );
 
 sub load {}
@@ -1715,7 +1870,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::INVLIST;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 __PACKAGE__->register_type( 12 );
 
 sub load {}
