@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Tool::Count;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 =head1 NAME
 
@@ -27,7 +27,9 @@ sub new { shift }
 
 =cut
 
-=head2 ( $kinds, $blessed ) = $count->count_svs( $df )
+=head2 count_svs
+
+   ( $kinds, $blessed ) = $count->count_svs( $df )
 
 Counts the different kinds of SV in the heap of the given
 L<Devel::MAT::Dumpfile> and returns two HASH references containing totals. The
