@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Tool::Inrefs;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use List::Util qw( pairmap pairs );
 
@@ -79,20 +79,32 @@ sub patch_inrefs
 
 This tool adds the following SV methods.
 
-=head2 @refs = $sv->inrefs
+=head2 inrefs
+
+   @refs = $sv->inrefs
 
 Returns a list of Reference objects for each of the SVs that refer to this
 one. This is formed by the inverse mapping along the SV graph from C<outrefs>.
 
-=head2 @refs = $sv->inrefs_strong
+=head2 inrefs_strong
 
-=head2 @refs = $sv->inrefs_weak
+=head2 inrefs_weak
 
-=head2 @refs = $sv->inrefs_direct
+=head2 inrefs_direct
 
-=head2 @refs = $sv->inrefs_indirect
+=head2 inrefs_indirect
 
-=head2 @refs = $sv->inrefs_inferred
+=head2 inrefs_inferred
+
+   @refs = $sv->inrefs_strong
+
+   @refs = $sv->inrefs_weak
+
+   @refs = $sv->inrefs_direct
+
+   @refs = $sv->inrefs_indirect
+
+   @refs = $sv->inrefs_inferred
 
 Returns lists of Reference objects filtered by type, analogous to the various
 C<outrefs_*> methods.
