@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Tool::Reachability;
 
@@ -10,7 +10,7 @@ use warnings;
 use feature qw( switch );
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use constant FOR_UI => 1;
 
@@ -307,7 +307,9 @@ sub mark_reachable
 
 This tool adds the following SV methods.
 
-=head2 $r = $sv->reachable
+=head2 reachable
+
+   $r = $sv->reachable
 
 Returns true if the SV is reachable from a known root.
 
