@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Tool::Sizes;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use constant FOR_UI => 1;
 
@@ -93,11 +93,15 @@ sub init_ui
 
 This tool adds the following SV methods.
 
-=head2 @svs = $sv->structure_set
+=head2 structure_set
+
+   @svs = $sv->structure_set
 
 Returns the total set of the SV's structure.
 
-=head2 $size = $sv->structure_size
+=head2 structure_size
+
+   $size = $sv->structure_size
 
 Returns the size, in bytes, of the structure that the SV contains.
 
@@ -137,11 +141,15 @@ sub Devel::MAT::SV::structure_size
    return sum0 map { $_->size } shift->structure_set
 }
 
-=head2 @svs = $sv->owned_set
+=head2 owned_set
+
+   @svs = $sv->owned_set
 
 Returns the set of every SV owned by the given one.
 
-=head2 $size = $sv->owned_size
+=head2 owned_size
+
+   $size = $sv->owned_size
 
 Returns the total size, in bytes, of the SVs owned by the given one.
 
